/*************************************************************************************
 *
 * Class to drive an I2C interfaced 7 segment LED display.
 * As per display at http://adafru.it/877
 *
 */

#include "stm32f4xx.h"
#include "stm32f4xx_i2c.h"

#define LED_ON 1
#define LED_OFF 0

#define HT16K33_BLINK_CMD 0x80
#define HT16K33_BLINK_DISPLAYON 0x01
#define HT16K33_BLINK_DISPLAYOFF 0x00
#define HT16K33_BLINK_OFF 0
#define HT16K33_BLINK_1HZ 2
#define HT16K33_BLINK_2HZ 1
#define HT16K33_BLINK_HALFHZ 3

#define HT16K33_BRIGHTNESS_CMD 0xE0

class HT16K33_Display {
public:
	HT16K33_Display(I2C_TypeDef *port, uint8_t i2c_addr);
	void setBrightness(uint8_t brightness);
	void blinkRate(uint8_t rate);
	void displayCmd(bool on);
	void displayOn(bool on);
	void clear(void);
	void print(uint16_t value);
    void colon(bool on);
    void error();
    void oil();
    void fuel();

	void init();
	uint8_t start();
	void stop();
	void sendData(uint8_t data);
private:
	void sendByte(uint8_t byte);
	void writeBuffer();
	uint8_t waitSR1Flags(uint32_t flags);
	uint8_t waitUntilIdle();
	uint8_t sendAddr(uint8_t dir);
	uint16_t displayBuffer[8];
	uint8_t addr;
	I2C_TypeDef *i2c;
};
